# Search-for-EPs


### Installation

You can install this package via `pip`.   

    pip install searchep    


### Documentation

The [documentation](https://search-for-eps.github.io/Search-for-EPs/) contains more details about this package.
